import { __extends, __assign } from './../external/tslib/tslib.es6.js';
import { Button } from '@highlight-ui/button';
import { Icon } from '@highlight-ui/icon';
import { Typography } from '@highlight-ui/typography';
import { parseMetadata, suffixMetadata } from '@highlight-ui/utils-commons';
import classnames from 'classnames';
import React from 'react';
import createTimer from './createTimer.js';
import variantToIconName from './variantToIconName.js';
import styles from './Toast.module.scss.js';
import themeToVariant from './themeToVariant.js';
var LEAVING_ANIMATION_DURATION = 200;

var Toast = function (_super) {
  __extends(Toast, _super);

  function Toast(props) {
    var _this = _super.call(this, props) || this;

    _this.closeTimer = null;
    _this.removeTimer = null;

    _this.close = function () {
      var onRequestToClose = _this.props.onRequestToClose;

      _this.clearCloseTimer();

      if (typeof onRequestToClose === 'function') {
        onRequestToClose();
      }
    };

    _this.startCloseTimer = function () {
      var _a = _this.props,
          autoClose = _a.autoClose,
          duration = _a.duration;

      if (autoClose && duration) {
        _this.closeTimer = createTimer(_this.close, duration);
      }
    };

    _this.clearCloseTimer = function () {
      if (_this.removeTimer) {
        clearTimeout(_this.removeTimer);
      }

      if (_this.closeTimer) {
        _this.closeTimer.reset();
      }
    };

    _this.handleMouseEnter = function () {
      if (_this.closeTimer) {
        _this.closeTimer.pause();
      }
    };

    _this.handleMouseLeave = function () {
      if (_this.closeTimer) {
        _this.closeTimer.resume();
      }
    };

    _this.state = {
      isVisible: true
    };
    return _this;
  }

  Toast.prototype.componentDidMount = function () {
    var onOpen = this.props.onOpen;

    if (onOpen) {
      onOpen();
    }

    this.startCloseTimer();
  };

  Toast.prototype.componentDidUpdate = function (prevProps) {
    var _a = this.props,
        isVisible = _a.isVisible,
        onRequestToRemove = _a.onRequestToRemove;

    if (prevProps.isVisible !== isVisible) {
      // eslint-disable-next-line react/no-did-update-set-state
      this.setState({
        isVisible: isVisible
      });

      if (!isVisible && typeof onRequestToRemove === 'function') {
        this.removeTimer = setTimeout(onRequestToRemove, LEAVING_ANIMATION_DURATION);
      }
    }
  };

  Toast.prototype.componentWillUnmount = function () {
    var onClose = this.props.onClose;

    if (onClose) {
      onClose();
    }

    this.clearCloseTimer();
  };

  Toast.prototype.render = function () {
    var state = this.state;
    var _a = this.props,
        actions = _a.actions,
        autoClose = _a.autoClose,
        className = _a.className,
        children = _a.children,
        duration = _a.duration,
        metadata = _a.metadata,
        onRequestToClose = _a.onRequestToClose,
        showCloseButton = _a.showCloseButton,
        theme = _a.theme,
        _b = _a.variant,
        variant = _b === void 0 ? 'highlight' : _b;
    var variantOrDeprecatedTheme = typeof theme !== 'undefined' ? themeToVariant(theme) : variant;
    var progressBarInner = classnames(styles.progressBarInner, styles[variantOrDeprecatedTheme]);
    var iconName = variantToIconName(variantOrDeprecatedTheme);
    var iconColor = "icon-" + variantOrDeprecatedTheme;
    return /*#__PURE__*/React.createElement("div", __assign({
      className: classnames(className, styles.container),
      role: "log"
    }, parseMetadata(metadata)), /*#__PURE__*/React.createElement("div", {
      "data-state": state.isVisible ? 'entering' : 'leaving',
      className: styles.inner,
      onMouseEnter: this.handleMouseEnter,
      onMouseLeave: this.handleMouseLeave
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.contentContainer
    }, /*#__PURE__*/React.createElement("div", {
      className: styles.iconContainer
    }, /*#__PURE__*/React.createElement(Icon, {
      name: iconName,
      color: iconColor,
      size: 20,
      type: "solid",
      metadata: suffixMetadata(metadata, 'icon')
    })), children && /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
      className: styles.bodyContainer
    }, /*#__PURE__*/React.createElement(Typography, {
      variant: "body-1",
      color: "text-default"
    }, children)), actions && /*#__PURE__*/React.createElement("div", __assign({
      className: styles.actionsContainer
    }, parseMetadata(suffixMetadata(metadata, 'actions-container'))), actions)), showCloseButton && /*#__PURE__*/React.createElement("div", {
      className: styles.closeButtonContainer
    }, /*#__PURE__*/React.createElement(Button, __assign({
      type: "button",
      className: styles.closeButton,
      tabIndex: -1,
      onClick: onRequestToClose
    }, parseMetadata(suffixMetadata(metadata, 'close-btn'))), /*#__PURE__*/React.createElement(Icon, {
      name: "times",
      color: "icon-on-secondary"
    })))), autoClose && duration && /*#__PURE__*/React.createElement("div", __assign({
      className: styles.progressBarContainer,
      role: "progressbar"
    }, parseMetadata(suffixMetadata(metadata, 'progress-bar'))), /*#__PURE__*/React.createElement("div", {
      className: progressBarInner,
      style: {
        animationDuration: duration / 1000 + "s"
      }
    }))));
  }; // eslint-disable-next-line react/static-property-placement


  Toast.defaultProps = {
    variant: 'highlight',
    autoClose: true,
    duration: 5000,
    showCloseButton: true,
    actions: undefined,
    onOpen: undefined,
    onClose: undefined
  };
  return Toast;
}(React.PureComponent);

export { Toast };
//# sourceMappingURL=Toast.js.map
