import { __extends, __assign, __spreadArray } from './../external/tslib/tslib.es6.js';
import React from 'react';
import { Toast } from './Toast.js';
import styles from './ToastManager.module.scss.js';

var hasCustomId = function (settings) {
  return Object.keys(settings).includes('id');
};

var ToastManager = function (_super) {
  __extends(ToastManager, _super);

  function ToastManager(props) {
    var _this = _super.call(this, props) || this;

    _this.getToastHandlers = function () {
      var toasts = _this.state.toasts;
      return toasts;
    };

    _this.closeAll = function () {
      var toasts = _this.getToastHandlers();

      toasts.forEach(function (toast) {
        if (toast && typeof toast.onRequestToClose === 'function') {
          toast.onRequestToClose();
        }
      });
    };

    _this.notify = function (options) {
      // If there's a custom toast ID passed, close existing toasts with the same custom ID
      if (hasCustomId(options)) {
        var toasts = _this.state.toasts;
        toasts.forEach(function (toast) {
          // Since unique ID is still appended to a custom ID, skip the unique ID and check only prefix
          if (toast.id && String(toast.id).startsWith(options.id || '')) {
            _this.closeToast(toast.id);
          }
        });
      }

      var toast = _this.createToastInstance(options);

      _this.setState(function (previousState) {
        return {
          toasts: __spreadArray([toast], previousState.toasts, true)
        };
      });

      return toast;
    };

    _this.createToastInstance = function (options) {
      if (options === void 0) {
        options = {
          children: null
        };
      }

      ToastManager.idCounter += 1;
      var uniqueId = ToastManager.idCounter;
      var id = hasCustomId(options) ? (options.id || '') + "-" + uniqueId : String(uniqueId);
      return __assign(__assign({}, options), {
        id: id,
        onRequestToClose: function () {
          return _this.closeToast(id);
        },
        onRequestToRemove: function () {
          return _this.removeToast(id);
        }
      });
    };

    _this.closeToast = function (id) {
      _this.setState(function (previousState) {
        return {
          toasts: previousState.toasts.map(function (toast) {
            if (toast.id === id) return __assign(__assign({}, toast), {
              isVisible: false
            });
            return toast;
          })
        };
      });
    };

    _this.removeToast = function (id) {
      _this.setState(function (previousState) {
        return {
          toasts: previousState.toasts.filter(function (toast) {
            return toast.id !== id;
          })
        };
      });
    };

    props.bindNotify(_this.notify); // props.bindGetToasts(this.getToasts); // TODO: Investigate why getToasts() never worked

    props.bindCloseAll(_this.closeAll);
    _this.state = {
      toasts: []
    };
    return _this;
  }

  ToastManager.prototype.render = function () {
    var toasts = this.state.toasts;
    return /*#__PURE__*/React.createElement("div", {
      className: styles.container
    }, toasts.map(function (props) {
      return /*#__PURE__*/React.createElement(Toast, __assign({
        key: props.id
      }, props));
    }));
  };

  ToastManager.idCounter = 0;
  return ToastManager;
}(React.PureComponent);

export { ToastManager as default };
//# sourceMappingURL=ToastManager.js.map
